@@ -4,7 +4,7 @@
 -- Copyright (C) 1999-2000 ArsDigita Corporation
 -- Author: Karl Goldstein (karlg@arsdigita.com)
 
--- $Id: content-template.sql,v 1.14.2.2 2005/01/06 18:43:27 daveb Exp $
+-- $Id: content-template.sql,v 1.23 2007/09/17 09:43:56 gustafn Exp $
 
 -- This is free software distributed under the terms of the GNU Public
 -- License.  Full text of the license is available from the GNU Project:
@@ -14,8 +14,11 @@ create view content_template_globals as
 select -200 as c_root_folder_id;
 
 create or replace function content_template__get_root_folder() returns integer as '
+declare
+  v_folder_id                 integer;
 begin
-  return content_template_globals.c_root_folder_id;
+  select c_root_folder_id from content_template_globals into v_folder_id;
+  return v_folder_id;
 end;' language 'plpgsql' immutable;
 
 -- create or replace package body content_template
@@ -197,7 +200,6 @@ begin
 end;' language 'plpgsql';
 
 select define_function_args('content_template__delete','template_id');
-
 create or replace function content_template__delete (integer)
 returns integer as '
 declare
@@ -209,6 +211,7 @@ begin
 end;' language 'plpgsql';
 
 -- function is_template
+select define_function_args('content_template__is_template','template_id');
 create or replace function content_template__is_template (integer)
 returns boolean as '
 declare
@@ -220,8 +223,8 @@ begin
  
 end;' language 'plpgsql' stable;
 
-
 -- function get_path
+select define_function_args('content_template__get_path','template_id,root_folder_id');
 create or replace function content_template__get_path (integer,integer)
 returns varchar as '
 declare
