@@ -3,7 +3,7 @@ ad_page_contract {
     
     @author Jon Griffin (jon@jongriffin.com)
     @creation-date 2000-10-04
-    @cvs-id $Id: reference-data-list.tcl,v 1.1 2001/08/28 04:00:52 jong Exp $
+    @cvs-id $Id: reference-data-list.tcl,v 1.2 2005/03/01 00:01:22 jeffd Exp $
 } {
 } -properties {
     context_bar:onevalue
@@ -17,7 +17,7 @@ set package_id [ad_conn package_id]
 set title "List Reference Data"
 set context_bar [list "$title"]
  
-set user_id [ad_verify_and_get_user_id]
+set user_id [ad_conn user_id]
 
 db_multirow data data_select { 
 }
