@@ -3,12 +3,12 @@
 -- Copyright (C) 1999-2000 ArsDigita Corporation
 -- Author: Hiro Iwashima (iwashima@mit.edu)
 
--- $Id: portraits.sql,v 1.1 2001/04/05 18:23:38 donb Exp $
+-- $Id: portraits.sql,v 1.2 2006/09/26 15:19:56 byronl Exp $
 
 create table user_portraits (
 	user_id		constraint user_portraits_user_id_fk
 			references users
-			constraint user_portraits_pk
+			constraint user_portraits_user_id_pk
 			primary key
 );
 
